The functions are rust implementations of functions from ethers.js library, one of the most popular web3 libraries out there. https://github.com/ethers-io/ethers.js/blob/master/packages/address/src.ts/index.ts
The functions are rust implementations of functions from ethers.js library, one of the most popular web3 libraries out there. https://github.com/ethers-io/ethers.js/blob/master/packages/address/src.ts/index.ts